@@ -10,34 +10,33 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.17';
-$DATE = '2004/04/07';
+$VERSION = '0.18';
+$DATE = '2004/04/08';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/Test_Tech.pm' => [qw(0.17 2004/04/07), 'revised 0.16'],
-    'MANIFEST' => [qw(0.17 2004/04/07), 'generated, replaces 0.16'],
-    'Makefile.PL' => [qw(0.17 2004/04/07), 'generated, replaces 0.16'],
-    'README' => [qw(0.17 2004/04/07), 'generated, replaces 0.16'],
-    'lib/Test/Tech.pm' => [qw(1.16 2004/04/07), 'revised 1.15'],
-    't/Test/Tech/Tech.d' => [qw(0.02 2004/04/07), 'revised 0.01'],
-    't/Test/Tech/Tech.pm' => [qw(0.02 2004/04/07), 'revised 0.01'],
-    't/Test/Tech/Tech.t' => [qw(0.15 2004/04/07), 'revised 0.14'],
-    't/Test/Tech/techA0.t' => [qw(0.1 2004/04/07), 'revised 0.09'],
-    't/Test/Tech/techA2.txt' => [qw(0.08 2004/04/07), 'revised 0.07'],
-    't/Test/Tech/techB0.t' => [qw(0.07 2004/04/07), 'revised 0.06'],
-    't/Test/Tech/techC0.t' => [qw(0.11 2004/04/07), 'revised 0.1'],
-    't/Test/Tech/techC2.txt' => [qw(0.09 2004/04/07), 'revised 0.08'],
-    't/Test/Tech/techD0.d' => [qw(0.04 2003/09/15), 'unchanged'],
+    'lib/Docs/Site_SVD/Test_Tech.pm' => [qw(0.18 2004/04/08), 'revised 0.17'],
+    'MANIFEST' => [qw(0.18 2004/04/08), 'generated, replaces 0.17'],
+    'Makefile.PL' => [qw(0.18 2004/04/08), 'generated, replaces 0.17'],
+    'README' => [qw(0.18 2004/04/08), 'generated, replaces 0.17'],
+    'lib/Test/Tech.pm' => [qw(1.17 2004/04/08), 'revised 1.16'],
+    't/Test/Tech/Tech.d' => [qw(0.03 2004/04/08), 'revised 0.02'],
+    't/Test/Tech/Tech.pm' => [qw(0.03 2004/04/08), 'revised 0.02'],
+    't/Test/Tech/Tech.t' => [qw(0.16 2004/04/08), 'revised 0.15'],
+    't/Test/Tech/techA0.t' => [qw(0.11 2004/04/08), 'revised 0.1'],
+    't/Test/Tech/techA2.txt' => [qw(0.08 2004/04/07), 'unchanged'],
+    't/Test/Tech/techB0.t' => [qw(0.08 2004/04/08), 'revised 0.07'],
+    't/Test/Tech/techC0.t' => [qw(0.12 2004/04/08), 'revised 0.11'],
+    't/Test/Tech/techC2.txt' => [qw(0.09 2004/04/07), 'unchanged'],
+    't/Test/Tech/techD0.d' => [qw(0.05 2004/04/08), 'revised 0.04'],
     't/Test/Tech/techD2.txt' => [qw(0.07 2003/09/15), 'unchanged'],
     't/Test/Tech/techD3.txt' => [qw(0.07 2003/09/15), 'unchanged'],
-    't/Test/Tech/techE0.t' => [qw(0.06 2004/04/07), 'new'],
-    't/Test/Tech/techE2.txt' => [qw(0.17 2004/04/07), 'new'],
-    'tlib/File/Package.pm' => [qw(1.13 2004/04/07), 'revised 1.12'],
-    'tlib/File/SmartNL.pm' => [qw(1.13 2004/04/07), 'revised 1.12'],
-    'tlib/Text/Scrub.pm' => [qw(1.11 2004/04/07), 'unchanged'],
-    'tlib/File/TestPath.pm' => [qw(1.11 2004/04/07), 'new'],
+    't/Test/Tech/techE0.t' => [qw(0.07 2004/04/08), 'revised 0.06'],
+    't/Test/Tech/techE2.txt' => [qw(0.17 2004/04/07), 'unchanged'],
+    't/Test/Tech/File/Package.pm' => [qw(1.13 2004/04/08), 'new'],
+    't/Test/Tech/File/SmartNL.pm' => [qw(1.13 2004/04/08), 'new'],
+    't/Test/Tech/Text/Scrub.pm' => [qw(1.11 2004/04/08), 'new'],
     't/Test/Tech/V001024/Test.pm' => [qw(1.25 2003/09/15), 'unchanged'],
     't/Test/Tech/V001015/Test.pm' => [qw(1.16 2003/09/15), 'unchanged'],
 
@@ -66,11 +65,11 @@ use vars qw(%INVENTORY);
 
  Test::Tech - Extends the Test program module
 
- Revision: P
+ Revision: R
 
- Version: 0.17
+ Version: 0.18
 
- Date: 2004/04/07
+ Date: 2004/04/08
 
  Prepared for: General Public 
 
@@ -137,7 +136,7 @@ session using the methods under test
 
 =head2 1.3 Document overview.
 
-This document releases Test::Tech version 0.17
+This document releases Test::Tech version 0.18
 providing description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -152,7 +151,7 @@ system file specification.
 
 This document releases the file 
 
- Test-Tech-0.17.tar.gz
+ Test-Tech-0.18.tar.gz
 
 found at the following repository(s):
 
@@ -224,28 +223,27 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/Test_Tech.pm                               0.17    2004/04/07 revised 0.16
- MANIFEST                                                     0.17    2004/04/07 generated, replaces 0.16
- Makefile.PL                                                  0.17    2004/04/07 generated, replaces 0.16
- README                                                       0.17    2004/04/07 generated, replaces 0.16
- lib/Test/Tech.pm                                             1.16    2004/04/07 revised 1.15
- t/Test/Tech/Tech.d                                           0.02    2004/04/07 revised 0.01
- t/Test/Tech/Tech.pm                                          0.02    2004/04/07 revised 0.01
- t/Test/Tech/Tech.t                                           0.15    2004/04/07 revised 0.14
- t/Test/Tech/techA0.t                                         0.1     2004/04/07 revised 0.09
- t/Test/Tech/techA2.txt                                       0.08    2004/04/07 revised 0.07
- t/Test/Tech/techB0.t                                         0.07    2004/04/07 revised 0.06
- t/Test/Tech/techC0.t                                         0.11    2004/04/07 revised 0.1
- t/Test/Tech/techC2.txt                                       0.09    2004/04/07 revised 0.08
- t/Test/Tech/techD0.d                                         0.04    2003/09/15 unchanged
+ lib/Docs/Site_SVD/Test_Tech.pm                               0.18    2004/04/08 revised 0.17
+ MANIFEST                                                     0.18    2004/04/08 generated, replaces 0.17
+ Makefile.PL                                                  0.18    2004/04/08 generated, replaces 0.17
+ README                                                       0.18    2004/04/08 generated, replaces 0.17
+ lib/Test/Tech.pm                                             1.17    2004/04/08 revised 1.16
+ t/Test/Tech/Tech.d                                           0.03    2004/04/08 revised 0.02
+ t/Test/Tech/Tech.pm                                          0.03    2004/04/08 revised 0.02
+ t/Test/Tech/Tech.t                                           0.16    2004/04/08 revised 0.15
+ t/Test/Tech/techA0.t                                         0.11    2004/04/08 revised 0.1
+ t/Test/Tech/techA2.txt                                       0.08    2004/04/07 unchanged
+ t/Test/Tech/techB0.t                                         0.08    2004/04/08 revised 0.07
+ t/Test/Tech/techC0.t                                         0.12    2004/04/08 revised 0.11
+ t/Test/Tech/techC2.txt                                       0.09    2004/04/07 unchanged
+ t/Test/Tech/techD0.d                                         0.05    2004/04/08 revised 0.04
  t/Test/Tech/techD2.txt                                       0.07    2003/09/15 unchanged
  t/Test/Tech/techD3.txt                                       0.07    2003/09/15 unchanged
- t/Test/Tech/techE0.t                                         0.06    2004/04/07 new
- t/Test/Tech/techE2.txt                                       0.17    2004/04/07 new
- tlib/File/Package.pm                                         1.13    2004/04/07 revised 1.12
- tlib/File/SmartNL.pm                                         1.13    2004/04/07 revised 1.12
- tlib/Text/Scrub.pm                                           1.11    2004/04/07 unchanged
- tlib/File/TestPath.pm                                        1.11    2004/04/07 new
+ t/Test/Tech/techE0.t                                         0.07    2004/04/08 revised 0.06
+ t/Test/Tech/techE2.txt                                       0.17    2004/04/07 unchanged
+ t/Test/Tech/File/Package.pm                                  1.13    2004/04/08 new
+ t/Test/Tech/File/SmartNL.pm                                  1.13    2004/04/08 new
+ t/Test/Tech/Text/Scrub.pm                                    1.11    2004/04/08 new
  t/Test/Tech/V001024/Test.pm                                  1.25    2003/09/15 unchanged
  t/Test/Tech/V001015/Test.pm                                  1.16    2003/09/15 unchanged
 
@@ -499,6 +497,13 @@ Added printout of the stats to the finish() subroutine.
 Added optional [@options] or {@options} input to the end of the ok subroutine and
 the skip subroutine.
 
+=item Test-Tech-0.18
+
+The test script could not find one of the test library program modules. Revamp
+the test script and test library modules and added steps to the ExtUtils::SVDmaker
+to have the SVDmaker test target run tests with just bare @INC that references
+a vigin Perl installation libraries only.
+
 =back
 
 =head2 3.4 Adaptation data.
@@ -523,18 +528,37 @@ and installation support are as follows:
 
 =item Installation Instructions.
 
-To installed the release file, use the CPAN module in the Perl release
+To installed the release file, use the CPAN module
+pr PPM module in the Perl release
 or the INSTALL.PL script at the following web site:
 
  http://packages.SoftwareDiamonds.com
 
 Follow the instructions for the the chosen installation software.
 
-The distribution file is at the following respositories:
+If all else fails, the file may be manually installed.
+Enter one of the following repositories in a web browser:
 
   http://www.softwarediamonds/packages/
   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/
 
+Right click on 'Test-Tech-0.18.tar.gz' and download to a temporary
+installation directory.
+Enter the following where $make is 'nmake' for microsoft
+windows; otherwise 'make'.
+
+ gunzip Test-Tech-0.18.tar.gz
+ tar -xf Test-Tech-0.18.tar
+ perl Makefile.PL
+ $make test
+ $make install
+
+On Microsoft operating system, nmake, tar, and gunzip 
+must be in the exeuction path. If tar and gunzip are
+not install, download and install unxutils from
+
+ http://packages.softwarediamonds.com
+
 =item Prerequistes.
 
  'Data::Secs2' => '0.01'
@@ -582,22 +606,6 @@ must be set to 1.
 Thus, the L<Test> module loads the L<Test::Tech> module into
 I<%Program_Line> hash instead of the Module Under Test.
 
-=item "Data::Dumper" stringification is not portable
-
-For numeric arrays, "L<Data::Dumper|Data::Dumper>" module will not
-stringify them the same for all Perls. The below Perl code will
-produce different results for different Perls
-
- $probe = 3;
- $actual = Dumper([0+$probe]);
-
-For Perl v5.6.1 MSWin32-x86-multi-thread, ActiveState build 631, binary,
-the results will be '[\'3\']'  
-while for Perl version 5.008 for solaris the results will be '[3]'. 
-
-The '[\'3\']' results is probable wrong, and the Perls that produce
-them are mutants that should be hunted down and killed.
-
 =back
 
 =head1 4.0 NOTES
@@ -655,11 +663,11 @@ __DATA__
 DISTNAME: Test-Tech^
 REPOSITORY_DIR: packages^
 
-VERSION : 0.17^
+VERSION : 0.18^
 FREEZE: 1^
 PREVIOUS_DISTNAME:  ^
-PREVIOUS_RELEASE: 0.16^
-REVISION: P^
+PREVIOUS_RELEASE: 0.17^
+REVISION: R^
 
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
 ABSTRACT: 
@@ -690,10 +698,9 @@ RESTRUCTURE:  ^
 AUTO_REVISE: 
 lib/Test/Tech.pm
 t/Test/Tech/*
-lib/File/Package.pm => tlib/File/Package.pm
-lib/File/SmartNL.pm => tlib/File/SmartNL.pm
-lib/Text/Scrub.pm => tlib/Text/Scrub.pm
-lib/File/TestPath.pm => tlib/File/TestPath.pm
+lib/File/Package.pm => t/Test/Tech/File/Package.pm
+lib/File/SmartNL.pm => t/Test/Tech/File/SmartNL.pm
+lib/Text/Scrub.pm => t/Test/Tech/Text/Scrub.pm
 ^
 
 REPLACE:
@@ -702,6 +709,7 @@ t/Test/Tech/V001015/*
 ^
 
 PREREQ_PM: 'Data::Secs2' => '0.01'^
+README_PODS: lib/Test/Tech.pm^
 
 TESTS: t/Test/Tech/Tech.t^
 EXE_FILES:  ^
@@ -955,6 +963,13 @@ Added printout of the stats to the finish() subroutine.
 Added optional [@options] or {@options} input to the end of the ok subroutine and
 the skip subroutine.
 
+\=item Test-Tech-0.18
+
+The test script could not find one of the test library program modules. Revamp
+the test script and test library modules and added steps to the ExtUtils::SVDmaker
+to have the SVDmaker test target run tests with just bare @INC that references
+a vigin Perl installation libraries only.
+
 \=back
 
 ^
@@ -1024,22 +1039,6 @@ must be set to 1.
 Thus, the L<Test> module loads the L<Test::Tech> module into
 I<%Program_Line> hash instead of the Module Under Test.
 
-\=item "Data::Dumper" stringification is not portable
-
-For numeric arrays, "L<Data::Dumper|Data::Dumper>" module will not
-stringify them the same for all Perls. The below Perl code will
-produce different results for different Perls
-
- $probe = 3;
- $actual = Dumper([0+$probe]);
-
-For Perl v5.6.1 MSWin32-x86-multi-thread, ActiveState build 631, binary,
-the results will be '[\'3\']'  
-while for Perl version 5.008 for solaris the results will be '[3]'. 
-
-The '[\'3\']' results is probable wrong, and the Perls that produce
-them are mutants that should be hunted down and killed.
-
 \=back
 ^
 
@@ -1094,16 +1093,35 @@ ANY WAY OUT OF THE POSSIBILITY OF SUCH DAMAGE.
 ^
 
 INSTALLATION:
-To installed the release file, use the CPAN module in the Perl release
+To installed the release file, use the CPAN module
+pr PPM module in the Perl release
 or the INSTALL.PL script at the following web site:
 
  http://packages.SoftwareDiamonds.com
 
 Follow the instructions for the the chosen installation software.
 
-The distribution file is at the following respositories:
+If all else fails, the file may be manually installed.
+Enter one of the following repositories in a web browser:
 
 ${REPOSITORY}
+
+Right click on '${DIST_FILE}' and download to a temporary
+installation directory.
+Enter the following where $make is 'nmake' for microsoft
+windows; otherwise 'make'.
+
+ gunzip ${BASE_DIST_FILE}.tar.${COMPRESS_SUFFIX}
+ tar -xf ${BASE_DIST_FILE}.tar
+ perl Makefile.PL
+ $make test
+ $make install
+
+On Microsoft operating system, nmake, tar, and gunzip 
+must be in the exeuction path. If tar and gunzip are
+not install, download and install unxutils from
+
+ http://packages.softwarediamonds.com
 ^
 
 SUPPORT: 603 882-0846 E<lt>support@SoftwareDiamonds.comE<gt>^
